@@ -64,14 +64,10 @@ void parse_cmdline(void) {
   if (!cmdline)
     return;
 
-  /* /proc/cmdline ends with '\n' instead of '\0',
-   * so don't rely on terminating '\0' (strlen()),
-   * and use ' ' and '\n' as delimiters. */
-
-  memset(buf, '\0', 1024);
   fread(buf, 1023, 1, cmdline);
+  buf[strlen(buf)] = '\0';
 
-  while ((tok = strsep(&bufp, " \n")) != NULL && bufp != NULL) {
+  while ((tok = strsep(&bufp, " ")) != NULL) {
     if (strncmp(tok, "quiet", 5) == 0)
       verbose = 0;
     if (strncmp(tok, "fsck.mode=skip", sizeof("fsck.mode=skip")) == 0)
@@ -331,7 +327,7 @@ int main(int argc, char **argv) {
   if (skip_and_exit)
     goto cmdline_skip;
 
-  plymouth_urgent(client, "Checking integrity, this may take some time (or try: fsck.mode=skip)");
+  plymouth_urgent(client, "Checking integrity, this may take some time");
   plymouth_keystrokes(client, "\x03", "Press Ctrl+C to cancel all filesystem checks in progress");
   md5_file = fopen(argv[2], "r");
   if (!md5_file) {
